"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const filterPackages_1 = require("./filterPackages");
const workspace_tools_1 = require("workspace-tools");
function getPipelinePackages(workspace, config) {
    // Filter packages per --scope and command(s)
    const { scope, since } = config;
    // If scoped is defined, get scoped packages
    const hasScopes = Array.isArray(scope) && scope.length > 0;
    let scopedPackages = undefined;
    if (hasScopes) {
        scopedPackages = workspace_tools_1.getScopedPackages(scope, workspace.allPackages);
        scopedPackages = [
            ...scopedPackages,
            ...workspace_tools_1.getTransitiveProviders(scopedPackages, workspace.allPackages),
        ];
    }
    const hasSince = typeof since !== "undefined";
    let changedPackages = undefined;
    if (hasSince) {
        changedPackages = workspace_tools_1.getChangedPackages(workspace.root, since, config.ignore);
    }
    return filterPackages_1.filterPackages({
        allPackages: workspace.allPackages,
        deps: config.deps,
        scopedPackages,
        changedPackages,
    });
}
exports.getPipelinePackages = getPipelinePackages;
